@@ -19,7 +19,9 @@ func TestJoinMessages(t *testing.T) {
 			wc := newTestConn(nil, &connBuf, true)
 			rc := newTestConn(&connBuf, nil, false)
 			for _, m := range messages {
-				wc.WriteMessage(BinaryMessage, []byte(m))
+				if err := wc.WriteMessage(BinaryMessage, []byte(m)); err != nil {
+					t.Fatalf("write %q: %v", m, err)
+				}
 			}
 
 			var result bytes.Buffer
